summaryrefslogtreecommitdiffstats
path: root/api/web_team_hub.go
diff options
context:
space:
mode:
Diffstat (limited to 'api/web_team_hub.go')
-rw-r--r--api/web_team_hub.go4
1 files changed, 3 insertions, 1 deletions
diff --git a/api/web_team_hub.go b/api/web_team_hub.go
index 6a25b7d3d..2c2386317 100644
--- a/api/web_team_hub.go
+++ b/api/web_team_hub.go
@@ -95,9 +95,11 @@ func ShouldSendEvent(webCon *WebConn, msg *model.Message) bool {
return false
}
} else {
// Don't share a user's view events with other users
if msg.Action == model.ACTION_CHANNEL_VIEWED {
return false
+ } else if msg.Action == model.ACTION_PREFERENCE_CHANGED {
+ return false
}
// Only report events to a user who is the subject of the event, or is in the channel of the event
@@ -95,9 +95,11 @@ func ShouldSendEvent(webCon *WebConn, msg *model.Message) bool {
}
} else {
- // Don't share a user's view events with other users
+ // Don't share a user's view or preference events with other users
if msg.Action == model.ACTION_CHANNEL_VIEWED {
return false